var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import '@nativescript/macos-node-api';
import { Event } from '../../dom/dom-utils.js';
import { native } from '../decorators/native.js';
import { view } from '../decorators/view.js';
import { View } from '../view/view.js';
export class ScrollChangeEvent extends Event {
    constructor(offset, eventDict) {
        super('scroll', eventDict);
        this.offset = offset;
        this.offset = offset;
    }
}
let NSScrollViewAutoResizable = class NSScrollViewAutoResizable extends NSScrollView {
    initScrollEvents(owner) {
        this._owner = new WeakRef(owner);
        NSNotificationCenter.defaultCenter.addObserverSelectorNameObject(this, 'boundsDidChange', NSViewBoundsDidChangeNotification, this?.contentView);
    }
    deinitScrollEvents() {
        NSNotificationCenter.defaultCenter.removeObserverNameObject(this, NSViewBoundsDidChangeNotification, this?.contentView);
    }
    boundsDidChange(_notification) {
        const view = this._owner?.deref();
        if (view) {
            view.dispatchEvent(new ScrollChangeEvent({
                x: view.nativeView.contentView.bounds.origin.x,
                y: view.nativeView.contentView.bounds.origin.y,
            }));
        }
    }
};
NSScrollViewAutoResizable.ObjCExposedMethods = {
    boundsDidChange: {
        returns: interop.types.void,
        params: [interop.types.id],
    },
};
NSScrollViewAutoResizable = __decorate([
    NativeClass
], NSScrollViewAutoResizable);
export { NSScrollViewAutoResizable };
let ScrollView = class ScrollView extends View {
    constructor() {
        super(...arguments);
        this.nativeView = undefined;
        this._disableDefaultDocumentView = false;
    }
    initNativeView() {
        this.nativeView = NSScrollViewAutoResizable.new();
        this.nativeView.hasVerticalScroller = true;
        this.nativeView.hasHorizontalScroller = false;
        this.nativeView.drawsBackground = false;
        this.nativeView.autohidesScrollers = true;
        this.nativeView.initScrollEvents(this);
        this.nativeView.contentView.postsBoundsChangedNotifications = true;
        return this.nativeView;
    }
    initDocumentView() {
        if (!this.documentView && !this._disableDefaultDocumentView) {
            this.documentView = document.createElement('view');
            this.documentView.style.overflow = 'scroll';
            super.insertBefore(this.documentView, null);
        }
    }
    disposeNativeView() {
        this.nativeView?.deinitScrollEvents();
        super.disposeNativeView();
    }
    insertBefore(node, child) {
        this.initDocumentView();
        if (this.documentView && !this._disableDefaultDocumentView) {
            this.documentView?.insertBefore(node, child);
        }
        else {
            if (this.firstChild)
                return node;
            super.insertBefore(node, child);
        }
        return node;
    }
    removeChild(child) {
        if (child === this.documentView || !this.documentView || this._disableDefaultDocumentView) {
            super.removeChild(child);
        }
        else {
            this.documentView?.removeChild(child);
        }
        return child;
    }
    addNativeChild(child) {
        this.nativeView.documentView = child.nativeView;
    }
    removeNativeChild(_child) {
        // @ts-expect-error documentView is nullable
        this.nativeView.documentView = null;
    }
    applyLayout(parentLayout) {
        super.applyLayout(parentLayout);
        this.nativeView.translatesAutoresizingMaskIntoConstraints = true;
    }
};
__decorate([
    native({
        setNative: (view, key, value) => {
            view.documentView.style = value;
        },
    }),
    __metadata("design:type", Object)
], ScrollView.prototype, "documentViewStyle", void 0);
__decorate([
    native({
        setNative: (view, key, value) => {
            view.initDocumentView();
            view.nativeView.hasHorizontalScroller = value;
            view.nativeView.hasVerticalScroller = !value;
            view.documentView.style = {
                flexDirection: value ? 'row' : 'column',
            };
            view.style = {
                flexDirection: 'row',
            };
        },
    }),
    __metadata("design:type", Boolean)
], ScrollView.prototype, "horizontal", void 0);
__decorate([
    native({
        setNative: (view, key, value) => {
            view._disableDefaultDocumentView = value;
            if (!value && view.firstChild !== view.documentView) {
                const firstChild = view.firstChild;
                view.removeChild(firstChild);
                view.initDocumentView();
                view.appendChild(firstChild);
            }
            else if (view.documentView) {
                const child = view.documentView.firstChild;
                view.documentView.removeChild(child);
                view.removeChild(view.documentView);
                view.appendChild(child);
            }
        },
    }),
    __metadata("design:type", Boolean)
], ScrollView.prototype, "disableDefaultDocumentView", void 0);
ScrollView = __decorate([
    view({
        name: 'HTMLScrollViewElement',
        tagName: 'scroll-view',
    })
], ScrollView);
export { ScrollView };
//# sourceMappingURL=scroll-view.js.map