var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Layout } from '../../layout/index.js';
import { overrides } from '../decorators/overrides.js';
import { view } from '../decorators/view.js';
import { TextBase } from './text-base.js';
let PaddingTextFieldCell = class PaddingTextFieldCell extends NSTextFieldCell {
    constructor() {
        super(...arguments);
        this.paddingTop = 0;
        this.paddingLeft = 0;
        this.paddingBottom = 0;
        this.paddingRight = 0;
    }
    cellSizeForBounds(forBounds) {
        const size = super.cellSizeForBounds(forBounds);
        size.height += this.paddingTop + this.paddingBottom;
        size.width += this.paddingLeft + this.paddingRight;
        return size;
    }
    titleRectForBounds(forBounds) {
        const rect = super.titleRectForBounds(forBounds);
        return CGRectInset(rect, this.paddingLeft, this.paddingTop);
    }
    editWithFrameInViewEditorDelegateEvent(rect, controlView, textObj, delegate, event) {
        const insetRect = CGRectInset(rect, this.paddingLeft, this.paddingTop);
        super.editWithFrameInViewEditorDelegateEvent(insetRect, controlView, textObj, delegate, event);
    }
    selectWithFrameInViewEditorDelegateStartLength(rect, controlView, textObj, delegate, selStart, selLength) {
        const insetRect = CGRectInset(rect, this.paddingLeft, this.paddingTop);
        super.selectWithFrameInViewEditorDelegateStartLength(insetRect, controlView, textObj, delegate, selStart, selLength);
    }
    drawInteriorWithFrameInView(cellFrame, controlView) {
        const insetRect = CGRectInset(cellFrame, this.paddingLeft, this.paddingTop);
        super.drawInteriorWithFrameInView(insetRect, controlView);
    }
};
PaddingTextFieldCell = __decorate([
    NativeClass
], PaddingTextFieldCell);
let Text = class Text extends TextBase {
    initNativeView() {
        this.nativeView = NSTextField.new();
        this.nativeCell = PaddingTextFieldCell.new();
        this.nativeView.cell = this.nativeCell;
        this.nativeView.lineBreakStrategy = NSLineBreakStrategy.None;
        this.nativeView.lineBreakMode = NSLineBreakMode.WordWrapping;
        return this.nativeView;
    }
    prepareNativeView(nativeView) {
        nativeView.isEditable = false;
        // nativeView.isSelectable = false;
        nativeView.drawsBackground = false;
        nativeView.isBordered = false;
        nativeView.isBezeled = false;
    }
    applyLayout(parentLayout) {
        super.applyLayout(parentLayout);
        if (this.nativeView) {
            this.nativeView.translatesAutoresizingMaskIntoConstraints = true;
        }
    }
    updateTextContent() {
        if (this.nativeView) {
            this.nativeView.stringValue = this.textContent || '';
            Layout.computeAndLayout(this);
        }
    }
    setPadding(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingTop = value;
            this.nativeCell.paddingRight = value;
            this.nativeCell.paddingBottom = value;
            this.nativeCell.paddingLeft = value;
        }
    }
    setPaddingTop(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingTop = value;
        }
        Layout.Setters.paddingTop(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingRight(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingRight = value;
        }
        Layout.Setters.paddingRight(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingBottom(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingBottom = value;
        }
        Layout.Setters.paddingBottom(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingLeft(_key, value, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingLeft = value;
        }
        Layout.Setters.paddingLeft(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
};
__decorate([
    overrides('padding'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPadding", null);
__decorate([
    overrides('paddingTop'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingTop", null);
__decorate([
    overrides('paddingRight'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingRight", null);
__decorate([
    overrides('paddingBottom'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingBottom", null);
__decorate([
    overrides('paddingLeft'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingLeft", null);
Text = __decorate([
    view({
        name: 'HTMLTextElement',
        tagName: 'text',
    })
], Text);
export { Text };
//# sourceMappingURL=text.js.map